@@ -1,6 +1,10 @@
-from ids_validator.checks.abstract_checker import AbstractChecker, CheckResults
+from ids_validator.checks.abstract_checker import (
+    AbstractChecker,
+    CheckResult,
+    CheckResults,
+)
 from ids_validator.ids_node import Node
-from ids_validator.utils import Log
+from ids_validator.models.validator_parameters import ValidatorParameters
 
 
 class AdditionalPropertyChecker(AbstractChecker):
@@ -11,14 +15,14 @@ class AdditionalPropertyChecker(AbstractChecker):
     must not exist.
     """
 
-    def run(self, node: Node, context: dict = None) -> CheckResults:
-        logs = []
+    @classmethod
+    def run(cls, node: Node, context: ValidatorParameters) -> CheckResults:
+        logs: CheckResults = []
 
         if node.get("type") != "object" and "additionalProperties" in node:
             logs.append(
-                (
-                    "'additionalProperties' can only be defined for 'type = object'",
-                    Log.CRITICAL.value,
+                CheckResult.critical(
+                    "'additionalProperties' can only be defined for 'type = object'"
                 )
             )
 
@@ -27,10 +31,9 @@ class AdditionalPropertyChecker(AbstractChecker):
             and node.get("additionalProperties") is not False
         ):
             logs.append(
-                (
+                CheckResult.critical(
                     "'additionalProperties' must be present and set to 'false' for "
-                    "'object' types",
-                    Log.CRITICAL.value,
+                    "'object' types"
                 )
             )
 
