@@ -1,6 +1,10 @@
-from ids_validator.checks.abstract_checker import AbstractChecker, CheckResults
+from ids_validator.checks.abstract_checker import (
+    AbstractChecker,
+    CheckResult,
+    CheckResults,
+    ValidatorParameters,
+)
 from ids_validator.ids_node import Node
-from ids_validator.utils import Log
 
 
 class RequiredPropertiesChecker(AbstractChecker):
@@ -11,15 +15,15 @@ class RequiredPropertiesChecker(AbstractChecker):
     logs a failure if the check fails.
     """
 
-    def run(self, node: Node, context: dict = None) -> CheckResults:
-        logs = []
+    @classmethod
+    def run(cls, node: Node, context: ValidatorParameters) -> CheckResults:
+        logs: CheckResults = []
         if node.has_required_list:
             missing_properties = node.missing_properties
             if missing_properties:
                 logs.append(
-                    (
-                        f"Required Properties are missing: {missing_properties}",
-                        Log.CRITICAL.value,
+                    CheckResult.critical(
+                        f"Required Properties are missing: {missing_properties}"
                     )
                 )
 
