@@ -1,6 +1,10 @@
-from ids_validator.checks.abstract_checker import AbstractChecker, CheckResults
+from ids_validator.checks.abstract_checker import (
+    AbstractChecker,
+    CheckResult,
+    CheckResults,
+    ValidatorParameters,
+)
 from ids_validator.ids_node import Node
-from ids_validator.utils import Log
 
 
 class TypeChecker(AbstractChecker):
@@ -8,12 +12,13 @@ class TypeChecker(AbstractChecker):
     is a valid JSON type or array of types
     """
 
-    def run(self, node: Node, context: dict = None) -> CheckResults:
-        logs = []
+    @classmethod
+    def run(cls, node: Node, context: ValidatorParameters) -> CheckResults:
+        logs: CheckResults = []
         type_is_valid, msg = node.has_valid_type
         if not type_is_valid:
             msg = msg if msg else f"Invalid 'type': {node.type_}"
-            logs.append((msg, Log.CRITICAL.value))
+            logs.append(CheckResult.critical(msg))
 
         properties = node.properties_dict
 
@@ -23,11 +28,10 @@ class TypeChecker(AbstractChecker):
         for key, val in properties.items():
             if isinstance(val, dict) and "type" not in val:
                 logs += [
-                    (
+                    CheckResult.critical(
                         f"'{node.path}.{key}' has no 'type' defined. This could be "
                         f"caused by a missing 'type', or a typo in a 'type' or '$ref' "
-                        f"keyword.",
-                        Log.CRITICAL,
+                        f"keyword."
                     )
                 ]
         return logs
