@@ -1,8 +1,12 @@
 from pydash import get
 
-from ids_validator.checks.abstract_checker import AbstractChecker, CheckResults
-from ids_validator.ids_node import Node
-from ids_validator.utils import Log
+from ids_validator.checks.abstract_checker import (
+    AbstractChecker,
+    CheckResult,
+    CheckResults,
+    ValidatorParameters,
+)
+from ids_validator.ids_node import Node, NodePath
 
 CONVENTION_VERSION_PATH = "properties.@idsConventionVersion"
 
@@ -14,9 +18,10 @@ class V1RootNodeChecker(AbstractChecker):
     It must be used in conjunction with generic RootNodeCheck.
     """
 
-    def run(self, node: Node, context: dict) -> CheckResults:
-        logs = []
-        if node.path == "roots":
+    @classmethod
+    def run(cls, node: Node, context: ValidatorParameters) -> CheckResults:
+        logs: CheckResults = []
+        if node.path == NodePath(("roots",)):
             convention_version = get(node, CONVENTION_VERSION_PATH)
             checks = [
                 get(convention_version, "type") == "string",
@@ -24,10 +29,9 @@ class V1RootNodeChecker(AbstractChecker):
             ]
             if not convention_version or not all(checks):
                 logs.append(
-                    (
+                    CheckResult.critical(
                         f"'{CONVENTION_VERSION_PATH}' must be of type 'string' with "
-                        f"non-empty 'const'",
-                        Log.CRITICAL.value,
+                        f"non-empty 'const'"
                     )
                 )
 
