@@ -5,7 +5,7 @@ NAME = f"{USERS}.items.properties.name"
 TYPE = f"{USERS}.items.properties.type"
 
 users_rules = {
-    USERS: {"type": "array", "min_properties": ["id", "name", "type"]},
+    USERS: {"type": "array"},
     ITEMS: {
         "type": "object",
     },
