@@ -1,4 +1,5 @@
 from enum import Enum
+from typing import Optional
 
 
 class Conventions(Enum):
@@ -6,11 +7,11 @@ class Conventions(Enum):
     V1_0_0 = "v1.0.0"
 
     @staticmethod
-    def get_by_value(convention_version):
+    def get_by_value(convention_version: str) -> Optional["Conventions"]:
+        """
+        Get the Conventions enum from its sting value, or if it doesn't exist,
+        return `None`
+        """
         for convention in Conventions:
             if convention.value == convention_version:
                 return convention
-
-    @staticmethod
-    def values():
-        return sorted([convention.value for convention in Conventions])
